/***************************************************************************
 *   Copyright (C) 2008 by Andreas Silberstorff   *
 *   taki@Rivendell   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SCHEDULERINTERFACE_H
#define SCHEDULERINTERFACE_H

#include <QObject>
#include <QDate>
#include <QTime>
#include <Data/Command>
#include <Data/DaysOfTheWeek>

namespace KalvaPlugin {

/**
 * This class describes the interface for kalva device plugins.
 *
 * Kalva device plugins have to implement this interface.
 *
 * The PluginManager reads in all plugins
 * and constructs a DeviceFactory for each device plugin.
 * DeviceFactories are held by the manager and can be accessed through
 * PluginManager::devices();
 *
 *  The plugin can be accessed through DeviceFactory::plugin().
 *
 * @short SchedulerInterface
 * @author Andreas Silberstorff <ml@andreas-silberstorff.de>
 * @version 1.0.91
 */

class SchedulerInterface
{
public:
	virtual ~SchedulerInterface() {};

	/**
	 * 
	 */
	virtual void setDate( QDate date ) = 0;

	/**
	 * 
	 */
	virtual void setTime( QTime time ) = 0;

	/**
	 *
	 */
	virtual void setDaysOfTheWeek( KalvaData::DaysOfTheWeek * daysOfTheWeek ) = 0;

	/**
	 * 
	 */
	virtual void setCommand( KalvaData::KalvaScriptCommand *command ) = 0;

};
}

Q_DECLARE_INTERFACE( KalvaPlugin::SchedulerInterface, "org.kde.apps.kalva2.SchedulerInterface/1.0" )

#endif // SCHEDULERINTERFACE_H
