/***************************************************************************
 *   Copyright (C) 2004 by Hans Oischinger                                 *
 *   hans.oischinger@kdemail.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#include "animatedlengthattr.h"
#include "lengthattribute.h"

// Visitors
#include "visitors/avisitor.h"

// KDE
#include <kdebug.h>

AnimatedLength::AnimatedLength() : Attribute(ATTR_LENGTH),
 m_baseVal(0),
 m_animVal(0)
{
  m_baseVal = new LengthAttribute(0.0f, LengthAttribute::SVG_LENGTHTYPE_PX);
  m_animVal = new LengthAttribute(0.0f, LengthAttribute::SVG_LENGTHTYPE_PX);
}

AnimatedLength::AnimatedLength(const AnimatedLength &other)
 : Attribute(ATTR_LENGTH),
 m_baseVal(0),
 m_animVal(0) 
{
  (*this) = other;
}

AnimatedLength::~AnimatedLength()
{
  delete m_baseVal;
  delete m_animVal;
}


AnimatedLength &AnimatedLength::operator=(const AnimatedLength &other)
{
  Attribute::operator=(other);
  delete m_baseVal;
  delete m_animVal;
  m_baseVal = new LengthAttribute(other.baseVal());
  m_animVal = new LengthAttribute(other.animVal());

  return *this;
}

Attribute* AnimatedLength::clone()
{
  AnimatedLength* retElem = new AnimatedLength();
  *retElem = *this;
  return ( retElem );
}

/**
 * Overrides default isValid() method and delegate request to baseVal
 * @return 
 */
bool AnimatedLength::isValid( ) const
{
  return m_baseVal->isValid();
}

void AnimatedLength::accept( AVisitor &a )
{
  a.visit(*this);
}
