/***************************************************************************
 * convertbase.h: implementation of ConvertBase class
 *
 * This file is part of KTabEdit, a KDE tabulature editor
 *
 * copyright (C) 2003-2006 the KTabEdit development team <mrgwen@gmail.com>
 * copyright (C) 2002-2003 the KGuitar development team <mrgwen@gmail.com>
 ***************************************************************************/

/***************************************************************************
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * See the file COPYING for more information.
 ***************************************************************************/

#ifndef CONVERT_BASE_H
#define CONVERT_BASE_H

class TabSong;

//! Abstract base class for all converters.
/*!
	Pure abstract base class to define basic structure of all
	converters - classes that manage loading / saving of internal
	KGuitar representation of tabulature data into some file format.
*/
class ConvertBase {
public:
	/*!
		Store the song var into the song class var.
		\param song The song.
	*/
	ConvertBase(TabSong *song) { this->song = song; };
	
	/*!
		Called to save current data from TabSong into file named
		fileName.
	*/
	virtual bool save(QString fileName) = 0;
	
	/*!
		Called to load data from file named fileName into TabSong.
	*/
	virtual bool load(QString fileName) = 0;
	
protected:
	//! The song to saved or load.
	TabSong *song;

};

#endif
