/*
Copyright 2008  Nathan Bradshaw nathanlbradshaw@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) version 3, or any
later version accepted by the membership of KDE e.V. (or its
successor approved by the membership of KDE e.V.), which shall
act as a proxy defined in Section 6 of version 3 of the license.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "query.h"
#include "query_p.h"

#include <QtCore/QHash>

using namespace ServiceModel;

Query::Query (Service *service,  QObject *parent) : QObject(parent), d_ptr(new QueryPrivate())
{
   Q_D(Query);
   
   this->setId(d->newId());
   d->m_service = service;
}

Query::Query(QueryPrivate &dd, Service *service, QObject *parent) : QObject(parent), d_ptr(&dd)
{
   Q_D(Query);
   
   this->setId(d->newId());
   d->m_service = service;
}

Query::~Query()
{
   delete d_ptr;
}

int Query::setId (int id)
{
   Q_D(Query);
   
   d->m_id = id;
   
   return id;
}

int Query::id ()
{
   Q_D(Query);
   
   return d->m_id;
}

void Query::addQueryParameter (const QString key, const QVariant val)
{
   Q_D(Query);
   
   d->addQueryParameter(key,val);
}

QHash<QString, QVariant> &Query::parameters()
{
   Q_D(Query);
   
   return d->m_queryParameters;
}

const ServiceModel::Service* Query::service ()
{
   Q_D(Query);
   
   return d->m_service;
}

// ServiceModel::Response* Query::response ()
// {
//   return 0;
// }
// 

