/*  This file is part of the KDE project
    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef PHONON_MIXERTOGGLECONTROL_H
#define PHONON_MIXERTOGGLECONTROL_H

#include "phonon_mixer_export.h"
#include "mixercontrol.h"

namespace Phonon
{
namespace Mixer
{

class MixerToggleControlPrivate;
class PHONON_MIXER_EXPORT MixerToggleControl : public MixerControl
{
    friend class Mixer;
    friend class MixerSharedData;
    friend MixerToggleControl mixercontrol_cast<MixerToggleControl>(const MixerControl &mc);
    friend MixerToggleControl qobject_cast<MixerToggleControl>(QObject *o);
    Q_DECLARE_PRIVATE(MixerToggleControl)
    public:
        enum Category {
            MuteLeftSwitch,
            MuteRightSwitch,
            MuteMonoSwitch
        };
        MixerToggleControl(const MixerToggleControl &);
        MixerToggleControl &operator=(const MixerToggleControl &);

        bool isChecked() const;
        Category category() const;

#if 0 // doxygen should pick this up:
    Q_SIGNALS:
        void toggled(bool);

    public Q_SLOTS:
#endif
        void setChecked(bool);

    protected:
        MixerToggleControl(MixerToggleControlPrivate &);
};

template<> PHONON_MIXER_EXPORT MixerToggleControl mixercontrol_cast<MixerToggleControl>(const MixerControl &mc);

} // namespace Mixer
} // namespace Phonon

template<> PHONON_MIXER_EXPORT Phonon::Mixer::MixerToggleControl qobject_cast<Phonon::Mixer::MixerToggleControl>(QObject *o);

#endif // PHONON_MIXERTOGGLECONTROL_H
